@@ -805,8 +805,10 @@ class IrcBot(object):
                 msg = re.sub(r"\003\d\d(?:,\d\d)?", "", msg)
                 debug(f"PARSED MESSAGE: {msg}")
 
-                if channel not in self.channels:
+                if channel not in self.channels and channel.startswith("#"):
+                    debug(f"TRYING TO PART {channel}")
                     await self._enqueue_message(f"PART {channel}")
+                    return
 
                 if (
                     channel in self.replyIntents
